"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var stream_1 = require("stream");
var plugin_error_1 = __importDefault(require("plugin-error"));
var plist_1 = __importDefault(require("plist"));
var bplist_parser_1 = require("bplist-parser");
var bplist_creator_1 = __importDefault(require("bplist-creator"));
var deepmerge_1 = __importDefault(require("deepmerge"));
var is_1 = require("./is");
var LIB_NAME = 'gulp-plist';
var defaultOptions = {
    writeBinary: false,
};
function createModifer(modifier) {
    if (typeof modifier === 'undefined') {
        throw new plugin_error_1.default(LIB_NAME, 'missing `modifier` argument');
    }
    if (is_1.isFunction(modifier)) {
        return modifier;
    }
    if (is_1.isPlainObject(modifier)) {
        return function (json) {
            return deepmerge_1.default(json, modifier, { isMergeableObject: is_1.isPlainObject });
        };
    }
    throw new plugin_error_1.default(LIB_NAME, '`modifier` must be a function or an object');
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function parsePlistData(data) {
    var magicBytes = data.contents.toString('ascii', 0, 6);
    if (magicBytes === 'bplist') {
        return bplist_parser_1.parseBuffer(data.contents)[0];
    }
    if (magicBytes === '<?xml ') {
        return plist_1.default.parse(data.contents.toString('utf8'));
    }
    throw new Error('Unknown plist format');
}
function default_1(modifier, options) {
    if (options === void 0) { options = {}; }
    var transform = new stream_1.Transform({ objectMode: true });
    var opts = Object.assign({}, defaultOptions, options || {});
    var mod = createModifer(modifier);
    transform._transform = function _transform(data, // eslint-disable-line @typescript-eslint/no-explicit-any
    encoding, callback) {
        // ignore null content
        if (data.isNull()) {
            return callback(null, null);
        }
        // stream is not supported
        if (data.isStream()) {
            this.emit('error', new plugin_error_1.default(LIB_NAME, 'Streaming is not supported'));
            return callback();
        }
        try {
            var json = mod(parsePlistData(data));
            data.contents = opts.writeBinary
                ? bplist_creator_1.default(json)
                : Buffer.from(plist_1.default.build(json));
        }
        catch (err) {
            this.emit('error', new plugin_error_1.default(LIB_NAME, err));
            return callback();
        }
        callback(null, data);
    };
    return transform;
}
exports.default = default_1;
//# sourceMappingURL=index.js.map